@@ -24,9 +24,13 @@ their Ubuntu One subscription and preferences.
 
 """
 
+import os
+
 # constants
 DBUS_BUS_NAME = "com.ubuntuone.controlpanel"
 DBUS_PREFERENCES_PATH = "/preferences"
 DBUS_PREFERENCES_IFACE = "com.ubuntuone.controlpanel.Preferences"
 
-WEBSERVICE_BASE_URL = u"https://one.ubuntu.com/api/"
+UBUNTUONE_BASE_URL = os.environ.get(
+    'UONE_BASE_URL', u'https://one.ubuntu.com').rstrip('/') + '/'
+WEBSERVICE_BASE_URL = UBUNTUONE_BASE_URL + u'api/'
