@@ -28,7 +28,12 @@ from twisted.internet.defer import (inlineCallbacks,
                                     DeferredLock)
 from ubuntuone.platform.credentials import CredentialsManagementTool
 
-from ubuntuone.controlpanel import sd_client, replication_client
+from ubuntuone.controlpanel import (
+    UBUNTUONE_BASE_URL,
+    WEBSERVICE_BASE_URL,
+    replication_client,
+    sd_client,
+)
 from ubuntuone.controlpanel.logger import setup_logging, log_call
 from ubuntuone.controlpanel.web_client import WebClient
 from ubuntu_sso.utils.webclient.common import (
@@ -73,8 +78,8 @@ STATUS_KEY = 'status'
 
 CONTACTS_PKG = 'thunderbird-couchdb'
 
-UBUNTUONE_FROM_OAUTH = u'https://one.ubuntu.com/api/1.0/from_oauth/'
-UBUNTUONE_LINK = u'https://one.ubuntu.com/'
+UBUNTUONE_FROM_OAUTH = WEBSERVICE_BASE_URL + u'1.0/from_oauth/'
+UBUNTUONE_LINK = UBUNTUONE_BASE_URL
 
 
 def append_path_sep(path):
