@@ -17,19 +17,12 @@
 """Export the control backend thru DBus."""
 
 from functools import wraps
-import sys
 
 import dbus.service
-# pylint: disable=E0611,W0404
-if 'gobject' in sys.modules:
-    import gobject as GObject
-else:
-    from gi.repository import GObject
-# pylint: enable=E0611,W0404
+from gi.repository import GObject
 
 from dbus.mainloop.glib import DBusGMainLoop
 from dbus.service import method, signal
-
 from twisted.python.failure import Failure
 from ubuntuone.syncdaemon.interaction_interfaces import bool_str
 
