@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -18,9 +18,7 @@
 
 import os
 
-# pylint: disable=W0611
-from ubuntuone.clientdefs import APP_NAME
-# pylint: enable=W0611
+from ubuntu_sso.constants import APP_NAME
 
 from ubuntu_sso.utils.translation import get_gettext
 
@@ -72,7 +70,7 @@ SERVICES_FILES_ICON = u'services-files.png'
 
 FILE_URI_PREFIX = u'file://'
 
-ACCEPT_SHARES = 'https://one.ubuntu.com/files/shareoffer/%s/'
+ACCEPT_SHARES = UBUNTUONE_LINK + u'files/shareoffer/%s/'
 CONTACTS_LINK = UBUNTUONE_LINK
 DASHBOARD = UBUNTUONE_LINK + u'dashboard/'
 EDIT_ACCOUNT_LINK = UBUNTUONE_LINK + u'account/'
