@@ -79,6 +79,11 @@ class ControlPanel(UbuntuOneBin):
         self.ui.tab_widget.setTabText(
             self.ui.tab_widget.indexOf(self.ui.share_links_tab),
                 MAIN_SHARE_LINKS_TAB)
+
+        # Workaround for bug LP: 1152388
+        handler = self.ui.share_links_tab.handle_current_tab_changed
+        self.ui.tab_widget.currentChanged.connect(handler)
+
         self.ui.tab_widget.setTabText(
             self.ui.tab_widget.indexOf(self.ui.devices_tab), MAIN_DEVICES_TAB)
         self.ui.tab_widget.setTabText(
