@@ -331,7 +331,8 @@ class FoldersPanel(UbuntuOneBin):
                     os.path.exists(volume_path))
         response = YES
         if subscribed and os.path.exists(volume_path):
-            if os.path.isdir(volume_path) and not is_link(volume_path):
+            if os.path.isdir(volume_path) and \
+                    not is_link(volume_path.encode("utf8")):
                 text = FOLDERS_CONFIRM_MERGE % {'folder_path': volume_path}
                 buttons = YES | NO | CANCEL
                 response = QtGui.QMessageBox.warning(self, '', text, buttons,
@@ -522,8 +523,8 @@ class LocalFoldersPanel(UbuntuOneBin):
             folders = []
             for _, _, volumes in volumes_info:
                 for volume in volumes:
-                    if (volume[u'type'] == self.backend.FOLDER_TYPE and
-                        bool(volume['subscribed'])):
+                    if volume[u'type'] == self.backend.FOLDER_TYPE and \
+                            bool(volume['subscribed']):
                         suggested = volume.get(u'suggested_path',
                             volume[u'display_name'])
                         folders.append((volume['path'], volume['volume_id'],
