@@ -116,8 +116,11 @@ class LoadingOverlay(QtGui.QFrame):
         if not self.timer:
             self.timer = self.startTimer(200)
 
-    # Invalid name "timerEvent"
-    # pylint: disable=C0103
+    def hideEvent(self, event):
+        """Stop that animation."""
+        if self.timer:
+            self.killTimer(self.timer)
+            self.timer = None
 
     def timerEvent(self, event):
         """Execute a loop to update the dot animation."""
