@@ -1,6 +1,6 @@
 # -*- coding: utf-8 *-*
 
-# Copyright 2012 Canonical Ltd.
+# Copyright 2012-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -107,6 +107,11 @@ class ShareLinksPanel(UbuntuOneBin):
         self.get_public_files()
         self._enhanced_line.btn_operation.hide()
 
+    def handle_current_tab_changed(self, index):
+        """Workaround for bug LP: 1152388"""
+        self.ui.line_search.clearFocus()
+        self.ui.line_search.popup.hide()
+
     @inlineCallbacks
     def share_file(self, file_path):
         """Clean the previous file share details and publish file_path."""
