@@ -36,6 +36,7 @@ logger = setup_logging('qt.share_links_search')
 HOME_DIR = ''
 AVOID_SECOND_ITEM = 2
 NORMAL_INCREMENT = 1
+SEARCH_TYPING_DELAY = 100       # msec
 
 
 def get_system_icon_for_filename(file_path):
@@ -63,7 +64,6 @@ class SearchBox(QtGui.QLineEdit, cache.Cache):
         self.current_results = []
         self.page_index = 0
         self.page_size = 20
-        self.pending_call = None
         self._post_key_event = {
             QtCore.Qt.Key_Escape: lambda *args: self.popup.hide(),
             QtCore.Qt.Key_Down: self._key_down_pressed,
@@ -76,6 +76,10 @@ class SearchBox(QtGui.QLineEdit, cache.Cache):
         self.popup.list_widget.verticalScrollBar().valueChanged.connect(
             self._scroll_fetch_more)
         self.textChanged.connect(self.handle_text_changed)
+        self._do_search_timer = QtCore.QTimer()
+        self._do_search_timer.timeout.connect(self._do_search)
+        self._do_search_timer.setInterval(SEARCH_TYPING_DELAY)
+        self._do_search_timer.setSingleShot(True)
 
         self._get_home_path()
 
@@ -94,30 +98,19 @@ class SearchBox(QtGui.QLineEdit, cache.Cache):
     def handle_text_changed(self, text):
         """Use delayed IPC to search for filenames after user stops typing."""
 
-        # Import here to avoid getting the wrong reactor due to import
-        # order. Save in class var to ease patching for tests:
-        if not self.qtreactor:
-            self.qtreactor = __import__('twisted').internet.reactor
         text = unicode(text)
         self.page_index = 0
 
         if text == '':
             self.popup.hide()
-            if self.pending_call and self.pending_call.active():
-                self.pending_call.cancel()
+            self._do_search_timer.stop()
             return
 
-        if self.pending_call and self.pending_call.active():
-            self.pending_call.reset(0.1)
-            return
-
-        self.pending_call = self.qtreactor.callLater(0.1, self._do_search)
+        self._do_search_timer.start(SEARCH_TYPING_DELAY)
 
     @inlineCallbacks
     def _do_search(self):
 
-        self.pending_call = None
-
         search_text = unicode(self.text())
         results = yield self.backend.search_files(search_text)
 
