@@ -18,6 +18,10 @@
 
 """Tests for the AddFolderButton widget."""
 
+import os
+
+from PyQt4 import QtCore
+
 from twisted.internet import defer
 
 from ubuntuone.controlpanel.gui.tests import (
@@ -28,9 +32,7 @@ from ubuntuone.controlpanel.gui.qt.tests import (
     BaseTestCase,
     CrashyBackend,
     CrashyBackendException,
-    FakedDialog,
-    FakedFileDialog,
-    set_path_on_file_dialog,
+    FakedDialog
 )
 
 # Access to a protected member
@@ -38,6 +40,36 @@ from ubuntuone.controlpanel.gui.qt.tests import (
 # pylint: disable=W0212, E1103
 
 
+def set_path_on_file_dialog(folder_name=None, file_dialog=None):
+    """Set a valid path in the file dialog to create a folder."""
+    if folder_name is None:
+        folder_name = 'Documents'
+    folder = os.path.join(USER_HOME, folder_name)
+    if file_dialog is None:
+        file_dialog = FakedFileDialog
+    file_dialog.response = QtCore.QString(folder)
+    return folder
+
+
+class FakedFileDialog(object):
+    """Fake a file chooser dialog."""
+
+    response = args = kwargs = None
+    DontUseNativeDialog = object()
+
+    @classmethod
+    def reset(cls, *a, **kw):
+        """Clear all values."""
+        cls.response = cls.args = cls.kwargs = None
+
+    @classmethod
+    def getExistingDirectory(cls, *a, **kw):
+        """Simulate a directory chooser."""
+        cls.args = a
+        cls.kwargs = kw
+        return cls.response
+
+
 class AddFolderButtonTestCase(BaseTestCase):
     """The test suite for the AddFolderButton."""
 
@@ -47,6 +79,12 @@ class AddFolderButtonTestCase(BaseTestCase):
     def setUp(self):
         yield super(AddFolderButtonTestCase, self).setUp()
         self.created_folders = []
+
+        # default response if user does nothing
+        FakedFileDialog.reset()
+
+        self.patch(gui, 'FileDialog', FakedFileDialog)
+
         self.patch(FakedFileDialog, 'response', gui.QtCore.QString(''))
         self.patch(self.ui.backend, 'validate_path_for_folder', lambda p: True)
         self.patch(self.ui, 'add_folder_func', self.add_folder)
