@@ -34,3 +34,10 @@ class LoadingOverlayTestCase(BaseTestCase):
         self.ui.show()
         self.assertTrue(self.ui.counter is not None)
         self.assertTrue(self.ui.orientation is not None)
+
+    def test_start_stop_timer(self):
+        """Showing the overlay starts a timer and hiding stops it."""
+        self.ui.show()
+        self.assertTrue(self.ui.timer is not None)
+        self.ui.hide()
+        self.assertTrue(self.ui.timer is None)
