@@ -254,6 +254,14 @@ class ShareLinksTestCase(BaseTestCase):
             os.path.basename(file_path))
         self.assertEqual(widget.ui.lbl_path.text(), file_path)
 
+    def test_hide_popup_on_tab_changed(self):
+        """Test that the popup is hidden by the tab changed signal."""
+
+        self.ui.ui.line_search.popup.show()
+        self.ui.handle_current_tab_changed(0)
+        self.assertFalse(self.ui.ui.line_search.popup.isVisible())
+        self.assertFalse(self.ui.ui.line_search.hasFocus())
+
 
 class ActionsButtonsTestCase(BaseTestCase):
     """Test the Actions Buttons."""
