@@ -60,6 +60,11 @@ class FakeMainWindow(QtGui.QWidget):
     def __init__(self, *args, **kwargs):
         self.args = (args, kwargs)
         super(FakeMainWindow, self).__init__()
+        self.tabname = ''
+
+    def switch_to(self, tabname):
+        """Fake switch_to."""
+        self.tabname = tabname
 
 
 class SystrayTestCase(BaseTestCase):
@@ -72,7 +77,6 @@ class SystrayTestCase(BaseTestCase):
     def setUp(self):
         # We need to patch the startTimer first, to avoid the timer
         # to get started on initialization.
-        self.patch(systray.TrayIcon, "startTimer", lambda s, x: None)
         self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
         yield super(SystrayTestCase, self).setUp()
         self.fake_desktop_service = FakeDesktopService()
@@ -249,6 +253,46 @@ class SystrayTestCase(BaseTestCase):
         tray.open_u1.trigger()
         self.assertEqual(self._called, ((), {}))
 
+    def test_open_share_file_no_window(self):
+        """Test the open_share_file option in the menu, with no window."""
+        self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
+        self.patch(ubuntuone.controlpanel.gui.qt.gui,
+            "MainWindow", FakeMainWindow)
+        tray = systray.TrayIcon()
+        self.assertEqual(tray.window, None)
+        tray.share_a_file.trigger()
+        self.assertIsInstance(tray.window, FakeMainWindow)
+        self.assertTrue(tray.window.isVisible())
+        self.assertEqual(tray.window.tabname, 'share_links')
+        self.assertEqual(tray.window.args, ((),
+            {'close_callback': tray.delete_window}))
+
+    def test_open_share_file(self):
+        """Test the open_share_file option in the menu, with a window."""
+        self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
+        tray = systray.TrayIcon()
+        window = FakeMainWindow()
+        tray.window = window
+        self.assertFalse(tray.window.isVisible())
+        tray.share_a_file.trigger()
+        self.assertEqual(tray.window, window)
+        self.assertEqual(tray.window.tabname, 'share_links')
+        self.assertTrue(tray.window.isVisible())
+
+    def test_open_share_file_window_minimized(self):
+        """Test the open_share_file option in the menu, with a min. window."""
+        self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
+        tray = systray.TrayIcon()
+        window = FakeMainWindow()
+        # This cannot be tested with the real activateWindow
+        # because the un-minimization is done by the WM, so
+        # it has a small delay, and it fails.
+        self.patch(window, "activateWindow", self._set_called)
+        tray.window = window
+        tray.share_a_file.trigger()
+        self.assertEqual(tray.window.tabname, 'share_links')
+        self.assertEqual(self._called, ((), {}))
+
     def test_delete_window(self):
         """Test deleting an existing window."""
         self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
@@ -337,7 +381,6 @@ class TransfersMenuTestCase(BaseTestCase):
     def setUp(self):
         # We need to patch the startTimer first, to avoid the timer
         # to get started on initialization.
-        self.patch(systray.TrayIcon, "startTimer", lambda s, x: None)
         self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
         yield super(TransfersMenuTestCase, self).setUp()
         self.fake_desktop_service = FakeDesktopService()
@@ -531,58 +574,3 @@ class TransfersMenuTestCase(BaseTestCase):
         current_actions = self.ui.transfers.actions()
 
         self.assertNotEqual(previous_actions, current_actions)
-
-
-class SharesTestCase(BaseTestCase):
-
-    """Test the info to be displayed in the shares section."""
-
-    class_ui = systray.TrayIcon
-
-    @inlineCallbacks
-    def setUp(self):
-        # We need to patch the startTimer first, to avoid the timer
-        # to get started on initialization.
-        self.patch(systray.TrayIcon, "startTimer", lambda s, x: None)
-        self.patch(systray.TransfersMenu, "startTimer", lambda s, x: None)
-        yield super(SharesTestCase, self).setUp()
-        self.fake_desktop_service = FakeDesktopService()
-        self.patch(QtGui, "QDesktopServices", self.fake_desktop_service)
-        self.patch(self.ui.backend, "get_shares", self.fake_get_backend)
-        self._shares_info = []
-
-    def fake_get_backend(self):
-        """Fake get_backend."""
-        return self._shares_info
-
-    def test_shares_refresh_not_reload(self):
-        """Check that we get the new info of shares but not reload the menu."""
-        actions = self.ui.context_menu.actions()
-        self.ui.load_menu()
-        post_actions = self.ui.context_menu.actions()
-        self.assertEqual(actions, post_actions)
-
-    def test_shares_refresh_reload(self):
-        """Check that we get the new info of shares but not reload the menu."""
-        actions = self.ui.context_menu.actions()
-        self._shares_info = [
-            {'accepted': False, 'other_visible_name': 'name',
-            'volume_id': 'asd123-asd123-asd123-asd123'}
-        ]
-        self.ui.load_menu()
-        post_actions = self.ui.context_menu.actions()
-        self.assertNotEqual(actions, post_actions)
-
-    def test_share_triggered(self):
-        """Check that we get the new info of shares but not reload the menu."""
-        volume_id = 'asd123-asd123-asd123-asd123'
-        self._shares_info = [
-            {'accepted': False, 'other_visible_name': 'name',
-            'volume_id': volume_id}
-        ]
-        self.ui.load_menu()
-        actions = self.ui.context_menu.actions()
-        share_action = actions[7]
-        share_action.trigger()
-        expected = QtCore.QUrl(systray.ACCEPT_SHARES % volume_id)
-        self.assertEqual(self.fake_desktop_service.opened_url, expected)
