@@ -40,6 +40,7 @@ class UbuntuOneBin(cache.Cache, QtGui.QWidget):
 
         self.overlay = LoadingOverlay(self)
         self.overlay.hide()
+        self._show_overlay = True
 
         self._is_processing = None
         self.is_processing = False
@@ -51,6 +52,21 @@ class UbuntuOneBin(cache.Cache, QtGui.QWidget):
 
         self._setup()
 
+    def _get_show_overlay(self):
+        """Get if the overlay will be shown."""
+        return self._show_overlay
+
+    def _set_show_overlay(self, is_shown):
+        """Set if the overlay will be shown."""
+        self._show_overlay = is_shown
+
+        if self._show_overlay and self._is_processing:
+            self.overlay.setVisible(is_shown)
+        else:
+            self.overlay.hide()
+
+    show_overlay = property(fget=_get_show_overlay, fset=_set_show_overlay)
+
     def _get_is_processing(self):
         """Get the value of is_processing."""
         return self._is_processing
@@ -62,7 +78,8 @@ class UbuntuOneBin(cache.Cache, QtGui.QWidget):
         If not is_processing, enable the UI and hide the spinner.
 
         """
-        self.overlay.setVisible(new_value)
+        if self._show_overlay:
+            self.overlay.setVisible(new_value)
         self.setEnabled(not new_value)
         self._is_processing = new_value
 
