@@ -91,12 +91,12 @@ FAKE_VOLUMES_NO_FREE_SPACE_INFO = [
      [{u'volume_id': u'0', u'name': u'full', u'path': u'full-share',
        u'subscribed': u'', u'type': ControlBackend.SHARE_TYPE,
        u'display_name': u'something',
-      }]),
+       }]),
     (u'Almost no free space', gui.SHARES_MIN_SIZE_FULL - 1,
      [{u'volume_id': u'1', u'name': u'almostfull', u'path': u'almost-full',
        u'subscribed': u'', u'type': ControlBackend.SHARE_TYPE,
        u'display_name': u'yadda',
-      }]),
+       }]),
 ]
 
 FAKE_VOLUMES_ONLY_ROOT_INFO = [(u'', u'5368709120', [ROOT])]
@@ -185,17 +185,17 @@ class FakeSignal(object):
 
     def __init__(self, *args, **kwargs):
         """Initialize."""
-        self.target = None
+        self.target = []
 
     def connect(self, target):
         """Fake connect."""
-        self.target = target
+        self.target.append(target)
 
     def disconnect(self, *args):
         """Fake disconnect."""
-        self.target = None
+        self.target = []
 
     def emit(self, *args):
         """Fake emit."""
-        if self.target:
-            self.target(*args)
+        for target in self.target:
+            target(*args)
