@@ -21,7 +21,9 @@
 import os
 import sys
 
-from ubuntuone.devtools.testcase import TestCase as BaseTestCase
+from twisted.internet import defer
+
+from ubuntuone.devtools.testcases import TestCase as BaseTestCase
 
 from ubuntuone.controlpanel.backend import (
     DEVICE_TYPE_COMPUTER, DEVICE_TYPE_PHONE,
@@ -332,15 +334,28 @@ SAMPLE_SHARED = [
 ]
 
 
+class CustomError(Exception):
+    """Custom error for tests."""
+
+
+def helper_fail(*a, **kw):
+    """Helper to raise an exception, usually used when monkey-patching."""
+    raise CustomError((a, kw))
+
+
 class TestCase(BaseTestCase):
     """Basics for testing."""
 
     assertIs = BaseTestCase.assertIdentical
 
+    @defer.inlineCallbacks
     def setUp(self):
+        yield super(TestCase, self).setUp()
         self._called = False
 
+    @defer.inlineCallbacks
     def tearDown(self):
+        yield super(TestCase, self).tearDown()
         self._called = False
 
     def _set_called(self, *args, **kwargs):
