@@ -746,3 +746,31 @@ class BasicTestCase(BaseTestCase):
         """Handle error when retrieving current syncdaemon status."""
         self.patch(self.sd.proxy, 'get_status', self.fake_fail)
         yield self.assertFailure(self.sd.get_current_status(), CustomError)
+
+
+class PublicFilesTestCase(BaseTestCase):
+    """Test for the public files syncdaemon client methods."""
+
+    @inlineCallbacks
+    def test_set_public_files_list_handler(self):
+        """Connect a handler to the public files signal."""
+        sample_handler = object()
+        yield self.sd.set_public_files_list_handler(sample_handler)
+        self.assertEqual(sample_handler,
+            self.sd.proxy.called['PublicFilesList'])
+
+    @inlineCallbacks
+    def test_set_public_access_changed_handler(self):
+        """Connect a handler to the public access changed signal."""
+        sample_handler = object()
+        yield self.sd.set_public_access_changed_handler(sample_handler)
+        self.assertEqual(sample_handler,
+            self.sd.proxy.called['PublicAccessChanged'])
+
+    @inlineCallbacks
+    def test_set_public_access_change_error_handler(self):
+        """Connect a handler to the public access change error signal."""
+        sample_handler = object()
+        yield self.sd.set_public_access_change_error_handler(sample_handler)
+        self.assertEqual(sample_handler,
+            self.sd.proxy.called['PublicAccessChangeError'])
