@@ -21,7 +21,6 @@ import sys
 
 from ubuntuone.controlpanel.logger import setup_logging
 
-
 logger = setup_logging('utils')
 
 DATA_SUFFIX = 'data'
@@ -38,6 +37,7 @@ no_op = lambda *args, **kwargs: None
 if sys.platform == 'win32':
     from ubuntuone.controlpanel.utils import windows
     add_to_autostart = windows.add_to_autostart
+    add_u1_folder_to_favorites = no_op
     are_updates_present = windows.are_updates_present
     default_folders = windows.default_folders
     install_config_and_daemons = no_op
@@ -46,14 +46,16 @@ if sys.platform == 'win32':
 elif sys.platform == 'darwin':
     from ubuntuone.controlpanel.utils import darwin
     add_to_autostart = no_op
-    are_updates_present = no_op
+    add_u1_folder_to_favorites = darwin.add_u1_folder_to_favorites
+    are_updates_present = darwin.are_updates_present
     default_folders = darwin.default_folders
     install_config_and_daemons = darwin.install_config_and_daemons
-    perform_update = no_op
+    perform_update = darwin.perform_update
     uninstall_application = no_op
 else:
     from ubuntuone.controlpanel.utils import linux
     add_to_autostart = no_op
+    add_u1_folder_to_favorites = no_op
     are_updates_present = no_op
     default_folders = linux.default_folders
     install_config_and_daemons = no_op
