@@ -371,12 +371,23 @@ def add_u1_folder_to_favorites():
     else:
         sud.setBool_forKey_(True, ADDED_TO_FINDER_SIDEBAR_ONCE)
 
-    u1_path = os.path.expanduser("~/Ubuntu%20One/")
-    u1_url = NSURL.URLWithString_("file://localhost" + "%s" % u1_path)
+    u1_path = os.path.expanduser("~/Ubuntu One/")
+    u1_url = NSURL.fileURLWithPath_isDirectory_(u1_path, True)
+
+    if u1_url is None:
+        logger.error("Error creating URL for favorites")
+        return
 
     lst = LSSharedFileListCreate(None,
                                  kLSSharedFileListFavoriteItems,
                                  None)
+    # LSSharedFileListCreate is wrapped by pyobjc, so we do not need
+    # to CFRelease(lst) here.
+
+    if lst is None:
+        logger.error("Error creating shared file list")
+        return
+
     item = LSSharedFileListInsertItemURL(lst, kLSSharedFileListItemBeforeFirst,
                                          None, None, u1_url, {}, [])
     if not isinstance(item, LSSharedFileListItemRef):
