@@ -109,11 +109,12 @@ class InstallConfigTestCase(TestCase):
                    self._set_called)
 
         def fake_stat(path):
-            fakestat = namedtuple('fakestat', ['st_mtime'])
+            fakestat = namedtuple('fakestat', ['st_mtime',
+                                               'st_size'])
             if path.startswith(self.APP_PATH):
-                return fakestat(src_mtime)
+                return fakestat(src_mtime, 0)
             else:
-                return fakestat(dest_mtime)
+                return fakestat(dest_mtime, 0)
 
         self.patch(utils.os, 'stat', fake_stat)
 
@@ -377,9 +378,8 @@ class AddU1FolderToFavoritesTestCase(CallRecordingTestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield super(AddU1FolderToFavoritesTestCase, self).setUp()
-        self.path = "/Users/a/Ubuntu%20One"
-        self.testurl = NSURL.URLWithString_("file://localhost" +
-                                            self.path)
+        self.path = "/Users/a/Ubuntu One"
+        self.testurl = NSURL.fileURLWithPath_isDirectory_(self.path, True)
 
         self.patch(utils.darwin.os.path, "expanduser",
                    lambda x: self.path)
