@@ -23,7 +23,7 @@ from twisted.internet import defer
 
 from ubuntuone.controlpanel import utils
 from ubuntuone.controlpanel.tests import TestCase
-from ubuntuone.devtools.testcases import skipIfJenkins
+from ubuntuone.devtools.testcases import skipIfJenkins, skipIf
 
 # let me use protected methods
 # pylint: disable=W0212
@@ -65,8 +65,6 @@ class AutoupdaterTestCase(TestCase):
         """Prepare for the diff tests."""
         yield super(AutoupdaterTestCase, self).setUp()
         self._base_path = r'path\to\exe'
-        self.auto_update_path = os.path.join(self._base_path,
-                                    utils.windows.AUTOUPDATE_EXE_NAME)
         self.return_from_call = 0
         self.command = None
         self.args = []
@@ -77,9 +75,11 @@ class AutoupdaterTestCase(TestCase):
             self.args = args
             return self.return_from_call
 
-        self.patch(utils.windows, 'getProcessValue', fake_execute_process)
-        self.patch(utils.windows, 'get_exe_path',
+        self.patch(utils.common, 'getProcessValue', fake_execute_process)
+        self.patch(utils.windows, 'get_bin_cmd',
                    lambda exe_name: os.path.join(self._base_path, exe_name))
+        self.patch(utils.common, 'get_update_config',
+                   lambda: ("URL", "VERSION", "CHANNEL", "CHECK"))
 
     @defer.inlineCallbacks
     def test_are_updates_present_true(self):
@@ -87,13 +87,15 @@ class AutoupdaterTestCase(TestCase):
         # the idea is simple, set the value to be returned from
         # the fake call, assert that we get true and also that
         # we did use the correct parameters.
-        self.return_from_call = 0
+        self.return_from_call = 1
         are_present = yield utils.are_updates_present()
         self.assertTrue(are_present, 'Updates should be present.')
         # lets assert that we did use the correct args
-        expected_args = ('--mode', 'unattended')
+        expected_args = [
+                utils.common.get_bin_cmd(utils.common.UPDATE_BIN_NAME)[1],
+                '--url', 'URL', '--current', 'VERSION',
+                '--release', 'CHANNEL']
         self.assertEqual(expected_args, self.args)
-        self.assertEqual(self.command, self.auto_update_path)
 
     @defer.inlineCallbacks
     def test_are_updates_present_false(self):
@@ -103,16 +105,22 @@ class AutoupdaterTestCase(TestCase):
         are_present = yield utils.are_updates_present()
         self.assertFalse(are_present, 'Updates should NOT be present.')
         # lets assert that we did use the correct args
-        expected_args = ('--mode', 'unattended')
+        expected_args = [
+                utils.common.get_bin_cmd(utils.common.UPDATE_BIN_NAME)[1],
+                '--url', 'URL', '--current', 'VERSION',
+                '--release', 'CHANNEL']
         self.assertEqual(expected_args, self.args)
-        self.assertEqual(self.command, self.auto_update_path)
 
     def test_perform_update(self):
         """Test the method that performs the update."""
         self.patch(utils.windows.win32api, 'ShellExecute', self._set_called)
         utils.perform_update()
-        args = (None, 'runas', self.auto_update_path,
-                '--unattendedmodeui none', '', 0)
+        args = [utils.common.get_bin_cmd(utils.common.UPDATE_BIN_NAME)[1],
+                '--url', 'URL', '--current', 'VERSION',
+                '--release', 'CHANNEL', '--install']
+        args = (None, 'runas',
+                utils.common.get_bin_cmd(utils.common.UPDATE_BIN_NAME)[0],
+                ' '.join(args), '', 0)
         self.assertEqual(self._called, (args, {}))
 
 
@@ -247,72 +255,7 @@ class DefaultFoldersTestCase(TestCase):
         self.test_special_folders(names=('PERSONAL', 'MYMUSIC', 'MYPICTURES'))
 
 
-class GetExePathTestCase(FrozenTestCase):
-    """Test the path calculator when sys is frozen."""
-
-    @defer.inlineCallbacks
-    def setUp(self):
-        """Set the different tests."""
-        yield super(GetExePathTestCase, self).setUp()
-        self.called = []
-        self.exists = True
-
-        def fake_abspath(path):
-            """Fake os.path.abspath."""
-            self.called.append('os.path.abspath')
-            return path
-
-        def fake_dirname(path):
-            """Fake os.path.dirname."""
-            self.called.append('os.path.dirname')
-            return path
-
-        def fake_exists(path):
-            """Fake os.path.exists."""
-            self.called.append('os.path.exists')
-            return self.exists
-
-        # patch the os.path functions used
-        self.patch(utils.windows.os.path, 'abspath', fake_abspath)
-        self.patch(utils.windows.os.path, 'dirname', fake_dirname)
-        self.patch(utils.windows.os.path, 'exists', fake_exists)
-
-    def test_get_exe_path(self):
-        """Test the method used to get the autoupdate."""
-        path = utils.windows.get_exe_path(exe_name=SOME_EXE_NAME)
-
-        self.assertEqual(os.path.join(self.executable, SOME_EXE_NAME), path)
-
-        expected = ['os.path.abspath', 'os.path.dirname', 'os.path.dirname',
-                    'os.path.exists']
-        self.assertEqual(expected, self.called)
-
-    def test_get_exe_path_not_present(self):
-        """Test the method used to get the autoupdate."""
-        self.exists = False
-
-        # called method and assert that we have the correct result
-        path = utils.windows.get_exe_path(exe_name=SOME_EXE_NAME)
-        self.assertTrue(path is None)
-
-
-class GetExePathNotFrozenTestCase(GetExePathTestCase):
-    """Test the path calculator when sys is not frozen."""
-
-    frozen = None
-
-    def test_get_exe_path(self):
-        """Test the method used to get the autoupdate."""
-        self.patch(utils.windows, '__file__', self.executable)
-
-        path = utils.windows.get_exe_path(exe_name=SOME_EXE_NAME)
-        self.assertEqual(os.path.join(self.executable, SOME_EXE_NAME), path)
-
-        expected = ['os.path.dirname', 'os.path.dirname', 'os.path.dirname',
-                    'os.path.exists']
-        self.assertEqual(expected, self.called)
-
-
+@skipIf(not getattr(sys, "frozen", False), "Only applicable when frozen")
 class UninstallApplicationTestCase(FrozenTestCase):
     """Test the uninstall_application helper when sys is frozen."""
 
@@ -327,7 +270,7 @@ class UninstallApplicationTestCase(FrozenTestCase):
         utils.uninstall_application()
 
         exe_name = utils.windows.UNINSTALL_EXE_NAME
-        uninstall_path = utils.windows.get_exe_path(exe_name=exe_name)
+        uninstall_path = utils.common.get_bin_cmd(exe_name=exe_name)[0]
         self.assertEqual(self._called,
             ((None, '', uninstall_path, '--mode win32', '', 0), {}))
 
